@@ -254,7 +254,7 @@ msr_normalize_header (MSRecord *msr, flag verbose)
   struct blkt_link_s *cur_blkt;
   hptime_t hptimems;
   int8_t usecoffset;
-  char seqnum[7];
+  char seqnum[11];
   int offset    = 0;
   int blktcnt   = 0;
   int reclenexp = 0;
@@ -277,7 +277,7 @@ msr_normalize_header (MSRecord *msr, flag verbose)
       msr->sequence_number = 1;
 
     /* Update values in the MSRecord.fsdh struct */
-    snprintf (seqnum, 7, "%06d", msr->sequence_number);
+    snprintf (seqnum, sizeof(seqnum), "%06d", msr->sequence_number);
     memcpy (msr->fsdh->sequence_number, seqnum, 6);
     msr->fsdh->dataquality = msr->dataquality;
     msr->fsdh->reserved    = ' ';
@@ -388,6 +388,12 @@ msr_duplicate (MSRecord *msr, flag datadup)
   /* Copy MSRecord structure */
   memcpy (dupmsr, msr, sizeof (MSRecord));
 
+  /* Reset pointers to not alias memory held by other structures */
+  dupmsr->fsdh = NULL;
+  dupmsr->blkts = NULL;
+  dupmsr->datasamples = NULL;
+  dupmsr->ststate = NULL;
+
   /* Copy fixed-section data header structure */
   if (msr->fsdh)
   {
@@ -395,7 +401,7 @@ msr_duplicate (MSRecord *msr, flag datadup)
     if ((dupmsr->fsdh = (struct fsdh_s *)malloc (sizeof (struct fsdh_s))) == NULL)
     {
       ms_log (2, "msr_duplicate(): Error allocating memory\n");
-      free (dupmsr);
+      msr_free (&dupmsr);
       return NULL;
     }
 
@@ -437,7 +443,7 @@ msr_duplicate (MSRecord *msr, flag datadup)
     {
       ms_log (2, "msr_duplicate(): unrecognized sample type: '%c'\n",
               msr->sampletype);
-      free (dupmsr);
+      msr_free (&dupmsr);
       return NULL;
     }
 
@@ -445,7 +451,7 @@ msr_duplicate (MSRecord *msr, flag datadup)
     if ((dupmsr->datasamples = (void *)malloc ((size_t) (msr->numsamples * samplesize))) == NULL)
     {
       ms_log (2, "msr_duplicate(): Error allocating memory\n");
-      free (dupmsr);
+      msr_free (&dupmsr);
       return NULL;
     }
 
