@@ -847,7 +847,7 @@ msr_update_header (MSRecord *msr, char *rawrec, flag swapflag,
   struct fsdh_s *fsdh;
   hptime_t hptimems;
   int8_t usecoffset;
-  char seqnum[7];
+  char seqnum[11];
 
   if (!msr || !rawrec)
     return -1;
@@ -858,7 +858,7 @@ msr_update_header (MSRecord *msr, char *rawrec, flag swapflag,
   fsdh = (struct fsdh_s *)rawrec;
 
   /* Pack values into the fixed section of header */
-  snprintf (seqnum, 7, "%06d", msr->sequence_number);
+  snprintf (seqnum, sizeof(seqnum), "%06d", msr->sequence_number);
   memcpy (fsdh->sequence_number, seqnum, 6);
 
   /* Get start time rounded to tenths of milliseconds and microsecond offset */
